function ec_calor(handles)
% EC_CALOR ( 'f(x)',Longitud,Constante_k,Tiempo_max,Nmero de trminos ) 
%   Graficacin en R3 de la ecuacin
%   de calor con las siguientes condiciones
%
%k=constante ka/c*rho
%   k D2u/Dx2 + P(x,t)= Du/Dt , 0<x<L , t>0
%   frontera :  u(0,t) = 0 , u(L,t) = 0 , t>0
%   u(x,0) = f(x) , 0<x<L
%   P(x,t)=0  (no habr fuente exxterna de calor)
%
%   El Tiempo_max y el Nmero_de_trminos son opcionales
%   se usa por defecto T=5 y N=20
%
%   Ejemplo
%   ec_calor( '100',pi,1,3,100 )
%   ec_calor( 'x^2+x',pi,1.6,3,100 )

%   
%   

Preguntas={'Funcion de temperatura inicial: '
'Longiitud'
'contante k'
'tiempo maximo'
'numero de terminos'};
Titulo = 'Entrada de Datos (Metodo analitico exacto)';
Defecto = {'x', '3.1415' , '1' , '3' , '100'};
datos=inputdlg(Preguntas, Titulo, 1, Defecto);
f=datos{1};
L=str2num(datos{2});
k=str2num(datos{3});
T=str2num(datos{4});
N=str2num(datos{5});

disp(f)
disp(L)
disp(k)
disp(T)
disp(N)

syms x n t
if nargin < 5, N=20; end
if nargin < 4, T=5; end

An = 2/L * int(f*sin((n*pi*x)/L),'x',0,L);
%pretty(An);
u = 0;
an = inline(An,'n');

for i=1:N
    
    u = u + an(i)*sin((i*pi*x)/L)*exp(-k*t*(i^2*pi^2/L^2));
    
end

 U = inline(u,'x','t');

ti = 0:0.1:T;
l = 0:0.1:L;
M = moviein(length(ti));
 axes(handles.axes1)
for i = 1:length(ti)
    clf
    axis equal
    hold on
    plot(l,U(l,ti(i))); 
    %plot(handles.axes2,l,U(l,ti(i)),'-k','LineWidth',3)
    grid on;
    title('Grfica de difusividad de calor')
    xlabel('X'),ylabel(['U(',num2str(L),' , t)'])
    legend(['Tiempo=',num2str(ti(i))])
    M(:,i) = getframe;
end
    movie(M)
    
pause(1)

[X,T] = meshgrid(0:0.1:L,0:0.1:T);

 axes(handles.axes2)
mesh(X,T,U(X,T))
xlabel('Longitud')
ylabel('Tiempo')
zlabel('Calor')



